@@ -1,10 +1,11 @@
 import os
 from io import BytesIO
 from pathlib import Path, PurePosixPath
-from uuid import UUID
 
+import pandas as pd
 import pytest
 from prefect import flow
+from prefect.deployments import Deployment
 
 from prefect_gcp.cloud_storage import (
     GcsBucket,
@@ -131,17 +132,14 @@ class TestGcsBucket:
         else:
             assert bucket_folder == ""
 
-    @pytest.mark.parametrize("path", [None, "subpath"])
+    @pytest.mark.parametrize("path", ["", ".", "/", "subpath"])
     def test_resolve_path(self, gcs_bucket, path):
         actual = gcs_bucket._resolve_path(path)
         bucket_folder = gcs_bucket.bucket_folder
-        if path is None:
-            dirname, filename = os.path.split(actual)
-            assert dirname == bucket_folder.rstrip("/")
-            assert UUID(filename, version=4)
-        else:
-            expected = str(PurePosixPath(bucket_folder) / path)
-            assert actual == expected
+        expected = str(PurePosixPath(bucket_folder) / path)
+        if expected in ["", "/", "."]:
+            expected = None
+        assert actual == expected
 
     def test_read_path(self, gcs_bucket):
         assert gcs_bucket.read_path("blob") == b"bytes"
@@ -207,6 +205,11 @@ class TestGcsBucket:
         bucket = gcs_bucket.get_bucket()
         assert bucket.name == "my-bucket"
 
+    def test_create_bucket(self, gcs_bucket):
+        bucket = gcs_bucket.create_bucket(location="us-east1")
+        assert bucket.name == "my-bucket"
+        assert bucket.location == "us-east1"
+
     @pytest.fixture
     def gcs_bucket_no_bucket_folder(self, gcp_credentials):
         return GcsBucket(
@@ -222,6 +225,15 @@ class TestGcsBucket:
             bucket_folder=request.param,
         )
 
+    @pytest.fixture
+    def pandas_dataframe(self):
+        return pd.DataFrame.from_dict(
+            {
+                "name": ["John Doe", "Jane Doe", "Johny", "Jane"],
+                "username": ["john.doe", "jane.doe", "johny", "jane"],
+            }
+        )
+
     def test_list_folders_with_root_only(self, gcs_bucket_with_bucket_folder):
         blobs = gcs_bucket_with_bucket_folder.list_folders()
         assert len(blobs) == 2
@@ -455,3 +467,83 @@ class TestGcsBucket:
             from_path, "to_path"
         )
         assert output_to_path == "base_folder/to_path"
+
+    def test_upload_from_dataframe_with_default_options(
+        self, gcs_bucket_with_bucket_folder, pandas_dataframe
+    ):
+        to_path = "to_path"
+        output_to_path = gcs_bucket_with_bucket_folder.upload_from_dataframe(
+            df=pandas_dataframe, to_path=to_path
+        )
+        assert output_to_path == "base_folder/to_path.csv.gz"
+
+    def test_upload_from_dataframe_with_parquet_output(
+        self, gcs_bucket_with_bucket_folder, pandas_dataframe
+    ):
+        to_path = "to_path"
+        output_to_path = gcs_bucket_with_bucket_folder.upload_from_dataframe(
+            df=pandas_dataframe, to_path=to_path, serialization_format="parquet"
+        )
+        assert output_to_path == "base_folder/to_path.parquet"
+
+    def test_upload_from_dataframe_with_parquet_snappy_output(
+        self, gcs_bucket_with_bucket_folder, pandas_dataframe
+    ):
+        to_path = "to_path"
+        output_to_path = gcs_bucket_with_bucket_folder.upload_from_dataframe(
+            df=pandas_dataframe,
+            to_path=to_path,
+            serialization_format="parquet_snappy",
+        )
+        assert output_to_path == "base_folder/to_path.parquet.snappy"
+
+    def test_upload_from_dataframe_with_parquet_gzip_output(
+        self, gcs_bucket_with_bucket_folder, pandas_dataframe
+    ):
+        to_path = "to_path"
+        output_to_path = gcs_bucket_with_bucket_folder.upload_from_dataframe(
+            df=pandas_dataframe,
+            to_path=to_path,
+            serialization_format="parquet_gzip",
+        )
+        assert output_to_path == "base_folder/to_path.parquet.gz"
+
+    def test_upload_from_dataframe_with_csv_output(
+        self, gcs_bucket_with_bucket_folder, pandas_dataframe
+    ):
+        to_path = "to_path"
+        output_to_path = gcs_bucket_with_bucket_folder.upload_from_dataframe(
+            df=pandas_dataframe, to_path=to_path, serialization_format="csv"
+        )
+        assert output_to_path == "base_folder/to_path.csv"
+
+    def test_upload_from_dataframe_with_csv_gzip_output(
+        self, gcs_bucket_with_bucket_folder, pandas_dataframe
+    ):
+        to_path = "to_path"
+        output_to_path = gcs_bucket_with_bucket_folder.upload_from_dataframe(
+            df=pandas_dataframe, to_path=to_path, serialization_format="csv_gzip"
+        )
+        assert output_to_path == "base_folder/to_path.csv.gz"
+
+    def test_upload_from_dataframe_with_invalid_serialization_should_raise_key_error(
+        self, gcs_bucket_with_bucket_folder, pandas_dataframe
+    ):
+        with pytest.raises(KeyError):
+            to_path = "to_path"
+            gcs_bucket_with_bucket_folder.upload_from_dataframe(
+                df=pandas_dataframe, to_path=to_path, serialization_format="pickle"
+            )
+
+    def test_basepath(self, gcs_bucket_with_bucket_folder, monkeypatch):
+        monkeypatch.setattr(
+            "prefect_gcp.GcpCredentials.get_cloud_storage_client", lambda x: x
+        )
+        assert gcs_bucket_with_bucket_folder.basepath == "base_folder/"
+
+        deployment = Deployment(
+            flow_name="test-flow-name",
+            name="test-deployment",
+            storage=gcs_bucket_with_bucket_folder,
+        )
+        assert deployment.location == ""
